summaryrefslogtreecommitdiffstats
path: root/perl-install/install_steps_interactive.pm
diff options
context:
space:
mode:
Diffstat (limited to 'perl-install/install_steps_interactive.pm')
-rw-r--r--perl-install/install_steps_interactive.pm12
1 files changed, 5 insertions, 7 deletions
diff --git a/perl-install/install_steps_interactive.pm b/perl-install/install_steps_interactive.pm
index 83155dffa..3b2e7fcda 100644
--- a/perl-install/install_steps_interactive.pm
+++ b/perl-install/install_steps_interactive.pm
@@ -511,14 +511,12 @@ such as ``mybox.mylab.myco.com''."),
}
install_steps::configureNetwork($o);
- #- added ppp configuration after ethernet one.
- if (!$::beginner && $o->ask_yesorno([ _("Modem Configuration") ],
- _("Do you want to configure a dialup connection with modem for your system?"), 0)) {
- $o->pppConfig;
+ #- added internet configuration after ethernet one.
+ if ($o->ask_yesorno([ _("Internet Configuration") ],
+ _("Do you want to configure an internet connection ?"), 0)) {
+ $o->{netcnx} ||= {};
+ netconnect::intro($o->{prefix}, $o->{netcnx}, $o, bool($o->{pcmcia})); #-dam's
}
- #- (dam's)
- $o->{netcnx} ||= {};
- netconnect::intro($o->{prefix}, $o->{netcnx}, $o, bool($o->{pcmcia}));
}
sub configureNetworkIntf {